==> digikam-0.10.0.tar.bz2: digikam-0.10.0/utilities/batch/batchthumbsgenerator.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2006-30-08
 * Description : batch thumbnails generator
 *
 * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef BATCHTHUMBSGENERATOR_H
#define BATCHTHUMBSGENERATOR_H

// Qt includes.

#include <QPixmap>
#include <QCloseEvent>

// Local includes.

#include "dprogressdlg.h"

class QWidget;
class QPixmap;

class KUrl;

namespace Digikam
{

class LoadingDescription;
class BatchThumbsGeneratorPriv;

class BatchThumbsGenerator : public DProgressDlg
{
    Q_OBJECT

public:

    BatchThumbsGenerator(QWidget* parent);
    ~BatchThumbsGenerator();

signals:

    void signalRebuildAllThumbsDone();

private:

    void abort();
    void complete();
    void processOne();

protected:

    void closeEvent(QCloseEvent *e);

protected slots:

    void slotCancel();

private slots:

    void slotRebuildThumbs();
    void slotGotThumbnail(const LoadingDescription&, const QPixmap&);

private:

    BatchThumbsGeneratorPriv* const d;
};

}  // namespace Digikam

#endif /* BATCHTHUMBSGENERATOR_H */

==> digikam-1.4.0.tar.bz2: digikam-1.4.0/utilities/batch/batchthumbsgenerator.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2006-30-08
 * Description : batch thumbnails generator
 *
 * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef BATCHTHUMBSGENERATOR_H
#define BATCHTHUMBSGENERATOR_H

// Qt includes

#include <QPixmap>
#include <QCloseEvent>

// Local includes

#include "dprogressdlg.h"

class QWidget;
class QPixmap;

class KUrl;

namespace Digikam
{

class LoadingDescription;
class BatchThumbsGeneratorPriv;

class BatchThumbsGenerator : public DProgressDlg
{
    Q_OBJECT

public:

    explicit BatchThumbsGenerator(QWidget* parent, bool rebuildAll=true);
    ~BatchThumbsGenerator();

Q_SIGNALS:

    void signalRebuildAllThumbsDone();

private:

    void abort();
    void complete();
    void processOne();

protected:

    void closeEvent(QCloseEvent *e);

protected Q_SLOTS:

    void slotCancel();

private Q_SLOTS:

    void slotRebuildThumbs();
    void slotGotThumbnail(const LoadingDescription&, const QPixmap&);

private:

    BatchThumbsGeneratorPriv* const d;
};

}  // namespace Digikam

#endif /* BATCHTHUMBSGENERATOR_H */
